@@ -19,6 +19,9 @@ use crossterm::event::Event;
 use std::{borrow::Cow, cell::Cell, convert::From, path::Path};
 use tui::{backend::Backend, layout::Rect, text::Span, Frame};
 
+//TODO: rename so that its clear this only works for Statuses
+//TODO: use new `filetreelist` crate
+
 ///
 pub struct FileTreeComponent {
     title: String,
@@ -417,8 +420,9 @@ impl Component for FileTreeComponent {
                         _ => Ok(EventState::NotConsumed),
                     }
                 } else if e == self.key_config.move_down {
-                    Ok(self.move_selection(MoveSelection::Down))
-                        .map(Into::into)
+                    Ok(self
+                        .move_selection(MoveSelection::Down)
+                        .into())
                 } else if e == self.key_config.move_up {
                     Ok(self.move_selection(MoveSelection::Up).into())
                 } else if e == self.key_config.home
