@@ -12,6 +12,8 @@ bitflags! {
         const DIFF = 0b010;
         /// commands might need updating (app::update_commands)
         const COMMANDS = 0b100;
+        /// branches have changed
+        const BRANCHES = 0b1000;
     }
 }
 
@@ -31,8 +33,10 @@ pub enum Action {
     StashDrop(CommitId),
     StashPop(CommitId),
     DeleteBranch(String),
+    DeleteTag(String),
     ForcePush(String, bool),
     PullMerge { incoming: usize, rebase: bool },
+    AbortMerge,
 }
 
 ///
@@ -45,6 +49,8 @@ pub enum InternalEvent {
     ShowErrorMsg(String),
     ///
     Update(NeedsUpdate),
+    ///
+    StatusLastFileMoved,
     /// open commit msg input
     OpenCommit,
     ///
@@ -54,8 +60,12 @@ pub enum InternalEvent {
     ///
     InspectCommit(CommitId, Option<CommitTags>),
     ///
+    SelectCommitInRevlog(CommitId),
+    ///
     TagCommit(CommitId),
     ///
+    Tags,
+    ///
     BlameFile(String),
     ///
     CreateBranch,
@@ -71,6 +81,8 @@ pub enum InternalEvent {
     Pull(String),
     ///
     PushTags,
+    ///
+    OpenFileTree(CommitId),
 }
 
 ///
