@@ -23,6 +23,9 @@ pub static PUSH_TAGS_STATES_DONE: &str = "done";
 pub fn title_branches() -> String {
     "Branches".to_string()
 }
+pub fn title_tags() -> String {
+    "Tags".to_string()
+}
 pub fn title_status(_key_config: &SharedKeyConfig) -> String {
     "Unstaged Changes".to_string()
 }
@@ -38,6 +41,9 @@ pub fn tab_status(key_config: &SharedKeyConfig) -> String {
 pub fn tab_log(key_config: &SharedKeyConfig) -> String {
     format!("Log [{}]", key_config.get_hint(key_config.tab_log))
 }
+pub fn tab_files(key_config: &SharedKeyConfig) -> String {
+    format!("Files [{}]", key_config.get_hint(key_config.tab_files))
+}
 pub fn tab_stashing(key_config: &SharedKeyConfig) -> String {
     format!(
         "Stashing [{}]",
@@ -62,15 +68,21 @@ pub fn msg_opening_editor(_key_config: &SharedKeyConfig) -> String {
 pub fn msg_title_error(_key_config: &SharedKeyConfig) -> String {
     "Error".to_string()
 }
-pub fn commit_title(_key_config: &SharedKeyConfig) -> String {
+pub fn commit_title() -> String {
     "Commit".to_string()
 }
-pub fn commit_title_amend(_key_config: &SharedKeyConfig) -> String {
+pub fn commit_title_merge() -> String {
+    "Commit (Merge)".to_string()
+}
+pub fn commit_title_amend() -> String {
     "Commit (Amend)".to_string()
 }
 pub fn commit_msg(_key_config: &SharedKeyConfig) -> String {
     "type commit message..".to_string()
 }
+pub fn commit_first_line_warning(count: usize) -> String {
+    format!("[subject length: {}]", count)
+}
 pub fn commit_editor_msg(_key_config: &SharedKeyConfig) -> String {
     r##"
 # Edit your commit message
@@ -83,7 +95,7 @@ pub fn stash_popup_title(_key_config: &SharedKeyConfig) -> String {
 pub fn stash_popup_msg(_key_config: &SharedKeyConfig) -> String {
     "type name (optional)".to_string()
 }
-pub fn confirm_title_reset(_key_config: &SharedKeyConfig) -> String {
+pub fn confirm_title_reset() -> String {
     "Reset".to_string()
 }
 pub fn confirm_title_stashdrop(
@@ -117,13 +129,18 @@ pub fn confirm_msg_merge(
         format!("Merge of {} incoming commits?", incoming)
     }
 }
-pub fn confirm_msg_reset(_key_config: &SharedKeyConfig) -> String {
+
+pub fn confirm_title_abortmerge() -> String {
+    "Abort merge?".to_string()
+}
+pub fn confirm_msg_abortmerge() -> String {
+    "This will revert all uncommitted changes. Are you sure?"
+        .to_string()
+}
+pub fn confirm_msg_reset() -> String {
     "confirm file reset?".to_string()
 }
-pub fn confirm_msg_reset_lines(
-    _key_config: &SharedKeyConfig,
-    lines: usize,
-) -> String {
+pub fn confirm_msg_reset_lines(lines: usize) -> String {
     format!(
         "are you sure you want to discard {} selected lines?",
         lines
@@ -154,6 +171,17 @@ pub fn confirm_msg_delete_branch(
 ) -> String {
     format!("Confirm deleting branch: '{}' ?", branch_ref)
 }
+pub fn confirm_title_delete_tag(
+    _key_config: &SharedKeyConfig,
+) -> String {
+    "Delete Tag".to_string()
+}
+pub fn confirm_msg_delete_tag(
+    _key_config: &SharedKeyConfig,
+    tag_name: &str,
+) -> String {
+    format!("Confirm deleting Tag: '{}' ?", tag_name)
+}
 pub fn confirm_title_force_push(
     _key_config: &SharedKeyConfig,
 ) -> String {
@@ -340,7 +368,7 @@ pub mod commands {
                 key_config.get_hint(key_config.move_right),
                 key_config.get_hint(key_config.move_left)
             ),
-            "navigate tree view",
+            "navigate tree view, collapse, expand",
             CMD_GROUP_GENERAL,
         )
     }
@@ -517,6 +545,16 @@ pub mod commands {
             CMD_GROUP_GENERAL,
         )
     }
+    pub fn abort_merge(key_config: &SharedKeyConfig) -> CommandText {
+        CommandText::new(
+            format!(
+                "Abort merge [{}]",
+                key_config.get_hint(key_config.abort_merge),
+            ),
+            "abort ongoing merge",
+            CMD_GROUP_GENERAL,
+        )
+    }
     pub fn select_staging(
         key_config: &SharedKeyConfig,
     ) -> CommandText {
@@ -843,6 +881,18 @@ pub mod commands {
             CMD_GROUP_LOG,
         )
     }
+    pub fn inspect_file_tree(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "Files [{}]",
+                key_config.get_hint(key_config.open_file_tree),
+            ),
+            "inspect file tree at specific revision",
+            CMD_GROUP_LOG,
+        )
+    }
     pub fn tag_commit_confirm_msg(
         key_config: &SharedKeyConfig,
     ) -> CommandText {
@@ -915,6 +965,18 @@ pub mod commands {
             CMD_GROUP_GENERAL,
         )
     }
+    pub fn merge_branch_popup(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "Merge [{}]",
+                key_config.get_hint(key_config.merge_branch),
+            ),
+            "merge a branch",
+            CMD_GROUP_GENERAL,
+        )
+    }
     pub fn select_branch_popup(
         key_config: &SharedKeyConfig,
     ) -> CommandText {
@@ -954,6 +1016,41 @@ pub mod commands {
         )
     }
 
+    pub fn open_tags_popup(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "Tags [{}]",
+                key_config.get_hint(key_config.tags),
+            ),
+            "open tags popup",
+            CMD_GROUP_GENERAL,
+        )
+    }
+    pub fn delete_tag_popup(
+        key_config: &SharedKeyConfig,
+    ) -> CommandText {
+        CommandText::new(
+            format!(
+                "Delete [{}]",
+                key_config.get_hint(key_config.delete_tag),
+            ),
+            "delete a tag",
+            CMD_GROUP_GENERAL,
+        )
+    }
+    pub fn select_tag(key_config: &SharedKeyConfig) -> CommandText {
+        CommandText::new(
+            format!(
+                "Select commit [{}]",
+                key_config.get_hint(key_config.select_tag),
+            ),
+            "Select commit in revlog",
+            CMD_GROUP_GENERAL,
+        )
+    }
+
     pub fn status_push(key_config: &SharedKeyConfig) -> CommandText {
         CommandText::new(
             format!(
