@@ -166,6 +166,18 @@ impl Revlog {
             tags.and_then(|tags| tags.get(&commit).cloned())
         })
     }
+
+    pub fn select_commit(&mut self, id: CommitId) -> Result<()> {
+        let position = self.git_log.position(id)?;
+
+        if let Some(position) = position {
+            self.list.select_entry(position);
+
+            Ok(())
+        } else {
+            anyhow::bail!("Could not select commit in revlog. It might not be loaded yet or it might be on a different branch.");
+        }
+    }
 }
 
 impl DrawableComponent for Revlog {
@@ -249,6 +261,21 @@ impl Component for Revlog {
                         .borrow_mut()
                         .push_back(InternalEvent::SelectBranch);
                     return Ok(EventState::Consumed);
+                } else if k == self.key_config.open_file_tree {
+                    return self.selected_commit().map_or(
+                        Ok(EventState::NotConsumed),
+                        |id| {
+                            self.queue.borrow_mut().push_back(
+                                InternalEvent::OpenFileTree(id),
+                            );
+                            Ok(EventState::Consumed)
+                        },
+                    );
+                } else if k == self.key_config.tags {
+                    self.queue
+                        .borrow_mut()
+                        .push_back(InternalEvent::Tags);
+                    return Ok(EventState::Consumed);
                 }
             }
         }
@@ -280,7 +307,7 @@ impl Component for Revlog {
 
         out.push(CommandInfo::new(
             strings::commands::log_tag_commit(&self.key_config),
-            true,
+            self.selected_commit().is_some(),
             self.visible || force_all,
         ));
 
@@ -293,17 +320,29 @@ impl Component for Revlog {
         ));
 
         out.push(CommandInfo::new(
-            strings::commands::copy_hash(&self.key_config),
+            strings::commands::open_tags_popup(&self.key_config),
             true,
             self.visible || force_all,
         ));
 
+        out.push(CommandInfo::new(
+            strings::commands::copy_hash(&self.key_config),
+            self.selected_commit().is_some(),
+            self.visible || force_all,
+        ));
+
         out.push(CommandInfo::new(
             strings::commands::push_tags(&self.key_config),
             true,
             self.visible || force_all,
         ));
 
+        out.push(CommandInfo::new(
+            strings::commands::inspect_file_tree(&self.key_config),
+            self.selected_commit().is_some(),
+            self.visible || force_all,
+        ));
+
         visibility_blocking(self)
     }
 
